Learn R Programming

CARBayesST (version 1.0)

print.carbayesST: Print a summary of the fitted model to the screen.

Description

This function takes a carbayesST object and returns a summary of the fitted model.

Usage

## S3 method for class 'carbayesST':
print(x, \dots)

Arguments

x
A carbayesST fitted model object
...
Ignored

Examples

Run this code
## See the examples in the main help file for CARBayes.

Run the code above in your browser using DataLab